@@ -108,6 +108,15 @@ void AIChatAssistant::setSelectedText(QString text)
 {
     m_selectedText=text;
 }
+/*!
+ * \brief preset query text
+ * This comes typically from a macro
+ * \param text
+ */
+void AIChatAssistant::setQueryText(const QString &text)
+{
+    leEntry->setText(text);
+}
 /*!
  * \brief start a new conversation
  */
@@ -124,6 +133,14 @@ void AIChatAssistant::clearConversation()
     AIQueryStorageModel *model=dynamic_cast<AIQueryStorageModel *>(treeView->model());
     model->addFileName(fileName);
 }
+/*!
+ * \brief execute query from outer level
+ * This is used when macros are involved
+ */
+void AIChatAssistant::executeQuery()
+{
+    slotSend();
+}
 /*!
  * \brief send question to ai provider
  */
@@ -191,6 +208,7 @@ void AIChatAssistant::slotSend()
         QJsonObject ja_message;
         ja_message["role"]="system";
         ja_message["content"]=config->ai_systemPrompt;
+        ja_messages.append(ja_message);
     }
     QJsonObject ja_message;
     ja_message["role"]="user";
@@ -282,8 +300,17 @@ void AIChatAssistant::slotInsert()
             }
         }
     }else{
-        // insert whole text
-        emit insertText(m_response);
+        // check if text=""" ... """ is repeated
+        // this is used to manipulate selected text
+        const int i=m_response.indexOf("text=\"\"\"");
+        if(i>=0){
+            int l=m_response.indexOf("\"\"\"",i+8); // find second delimiter
+            m_response=m_response.mid(i+8,l-8-i);
+            emit insertText(m_response);
+        }else{
+            // insert whole text
+            emit insertText(m_response);
+        }
     }
 }
 /*!
