@@ -3,19 +3,13 @@
 
 #include "mostQtHeaders.h"
 
-#include "latexparser/latexparser.h"
+#include "latexparser/latex2text.h"
 #include "configmanagerinterface.h"
 
-
-//TODO: move this away
 #include "grammarcheck_config.h"
 class QDocumentLineHandle;
 class LatexDocument;
 
-struct LineInfo {
-    QDocumentLineHandle* line;
-	QString text;
-};
 
 enum GrammarErrorType { GET_UNKNOWN = 0, GET_WORD_REPETITION, GET_LONG_RANGE_WORD_REPETITION, GET_BAD_WORD, GET_BACKEND, GET_BACKEND_SPECIAL1, GET_BACKEND_SPECIAL2, GET_BACKEND_SPECIAL3, GET_BACKEND_SPECIAL4};
 
@@ -38,10 +32,8 @@ struct LineResult {
 	QList<GrammarError> errors;
 };
 
-Q_DECLARE_METATYPE(LineInfo)
 Q_DECLARE_METATYPE(GrammarError)
 Q_DECLARE_METATYPE(GrammarErrorType)
-Q_DECLARE_METATYPE(QList<LineInfo>)
 Q_DECLARE_METATYPE(QList<GrammarError>)
 
 struct LanguageGrammarData {
@@ -84,7 +76,7 @@ private:
 	QString languageFromHunspellToLanguageTool(QString language);
 	QString languageFromLanguageToolToHunspell(QString language);
 	LTStatus ltstatus;
-	LatexParser *latexParser;
+    QSharedPointer<LatexParser> latexParser;
 	GrammarCheckerConfig config;
 	GrammarCheckBackend *backend;
 	QMap<QString, LanguageGrammarData> languages;
