@@ -7,7 +7,7 @@
 #include "codesnippet.h"
 #include "bibtexparser.h"
 #include "latexparser.h"
-#include "usermacro.h"
+//#include "usermacro.h"
 #include "syntaxcheck.h"
 #include "grammarcheck.h"
 #include "latexpackage.h"
@@ -44,6 +44,7 @@ struct UserCommandPair {
 	// information for code completion
 	CodeSnippet snippet;
 	UserCommandPair(const QString &name, const CodeSnippet &snippet);
+    UserCommandPair(const QString &name, const QString &snippet);
 };
 
 
@@ -72,13 +73,12 @@ public:
     Q_INVOKABLE LatexEditorView *getEditorView() const;
 	QString getFileName() const;
 	QFileInfo getFileInfo() const;
-	//QSet<QString> texFiles; //absolute file names, also contains fileName
+    void setAsImportedFile(bool state);
+    bool getStateImportedFile();
 
     Q_PROPERTY(QString fileName READ getFileName)
     Q_PROPERTY(QFileInfo fileInfo READ getFileInfo)
-#if (QT_VERSION<QT_VERSION_CHECK(6,0,0))
     Q_PROPERTY(LatexEditorView *editorView READ getEditorView)
-#endif
 
 	bool isHidden(); ///< true if editor is not displayed
 
@@ -92,9 +92,9 @@ public:
 
 	friend class SyntaxCheckTest;
     friend class LatexEditorViewTest;
-	friend class LatexStructureMerger;
-	friend class LatexStructureMergerMerge;
 	friend class ScriptEngineTest;
+    friend class LatexDocumentTest;
+    friend class TexStudioTest;
 
 private:
 	static QStringList someItems(const QMultiHash<QDocumentLineHandle *, ReferencePair> &list);
@@ -106,7 +106,7 @@ public:
 	Q_INVOKABLE QStringList refItems() const; ///< all references in this document
 	Q_INVOKABLE QStringList bibItems() const; ///< all bibitem defined in this document
 	Q_INVOKABLE QList<CodeSnippet> userCommandList() const; ///< all user commands defined in this document, sorted
-	Q_INVOKABLE CodeSnippetList additionalCommandsList();
+    Q_INVOKABLE CodeSnippetList additionalCommandsList(QStringList &loadedFiles);
 	void updateRefsLabels(const QString &ref);
     void recheckRefsLabels(QList<LatexDocument *> listOfDocs=QList<LatexDocument*>(), QStringList items=QStringList());
     static void updateRefHighlight(ReferencePairEx p);
@@ -118,6 +118,8 @@ public:
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getLabels(const QString &name); ///< get line/column from label name
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getRefs(const QString &name); ///< get line/column from reference name
 	Q_INVOKABLE QMultiHash<QDocumentLineHandle *, int> getBibItems(const QString &name);
+    LatexDocument *getDocumentForLabel(const QString &name); ///< get document from label name
+    int countCommandDefintions(const QString &name, const QString word=""); ///< count how many time a certain command is defined, used for checking for duplicates
 	Q_INVOKABLE QDocumentLineHandle *findCommandDefinition(const QString &name); ///< get line of definition from command name (may return nullptr)
 	Q_INVOKABLE QDocumentLineHandle *findUsePackage(const QString &name); ///< get line of \usepackage from package name (may return nullptr)
 	Q_INVOKABLE void replaceItems(QMultiHash<QDocumentLineHandle *, ReferencePair> items, const QString &newName, QDocumentCursor *cursor = nullptr);
@@ -125,15 +127,8 @@ public:
     Q_INVOKABLE void replaceRefs(const QString &name, const QString &newName, QDocumentCursor *cursor = nullptr);
 	Q_INVOKABLE void replaceLabelsAndRefs(const QString &name, const QString &newName);
 
-	void patchLinesContaining(const QStringList cmds);
-
-	StructureEntry *baseStructure;
-
 	QDocumentSelection sectionSelection(StructureEntry *section);
-	void clearAppendix()
-	{
-        mAppendixLine = nullptr;
-	}
+    void clearAppendix();
 	StructureEntry *findSectionForLine(int currentLine);
 
 	LatexDocuments *parent;
@@ -148,33 +143,25 @@ public:
 	void addChild(LatexDocument *doc);
 	void removeChild(LatexDocument *doc);
 	bool containsChild(LatexDocument *doc) const;
-	Q_INVOKABLE LatexDocument *getMasterDocument() const
-	{
-		return masterDocument;
-	}
-    const LatexDocument *getRootDocument(QSet<const LatexDocument *> *visitedDocs = nullptr) const;
+    Q_INVOKABLE LatexDocument *getMasterDocument() const;
+    const LatexDocument *getRootDocument(QSet<const LatexDocument *> *visitedDocs = nullptr, bool breakAtSubfileRoot=false) const;
 	Q_INVOKABLE LatexDocument *getRootDocument();
-	Q_INVOKABLE LatexDocument *getTopMasterDocument()
-	{
-		return getRootDocument();    // DEPRECATED: only the for backward compatibility of user scripts
-	}
+    Q_INVOKABLE LatexDocument *getTopMasterDocument();
 
-	Q_INVOKABLE QStringList includedFiles();
+    Q_INVOKABLE QStringList includedFiles(bool importsOnly=false);
 	Q_INVOKABLE QStringList includedFilesAndParent();
-    Q_INVOKABLE QList<LatexDocument *> getListOfDocs(QSet<LatexDocument *> *visitedDocs = nullptr);
+    Q_INVOKABLE QList<LatexDocument *> getListOfDocs(QSet<LatexDocument *> *visitedDocs = nullptr,bool onlyChildDocs=false);
 
-	LatexParser ltxCommands, lp;
+    LatexParser ltxCommands; /// locally defined latex commands
+    QSharedPointer<LatexParser> lp;
 
 	Q_INVOKABLE bool containsPackage(const QString &name);
 	Q_INVOKABLE QStringList containedPackages();
-    Q_INVOKABLE QSet<QString> usedPackages();
-    bool updateCompletionFiles(const bool forceUpdate,const bool forceLabelUpdate = false,const bool delayUpdate = false);
+    Q_INVOKABLE QSet<QString> usedPackages(bool onlyInChildDocs=false);
+    bool updateCompletionFiles(const bool updatePackages=true,const bool updateUserCommands=true);
     const QSet<QString> &getCWLFiles() const;
 
-	Q_INVOKABLE QString spellingDictName() const
-	{
-		return mSpellingDictName;
-	}
+    Q_INVOKABLE QString spellingDictName() const;
 	Q_INVOKABLE QString getMagicComment(const QString &name) const;
 	Q_INVOKABLE StructureEntry *getMagicCommentEntry(const QString &name) const;
     Q_INVOKABLE void updateMagicComment(const QString &name, const QString &val, bool createIfNonExisting = false, QString prefix="!TeX");
@@ -201,31 +188,65 @@ public:
 	void reCheckSyntax(int lineStart = 0, int lineNum = -1);
 	QString getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironment previous, TokenStack stack);
 
-	void getEnv(int lineNumber, StackEnvironment &env); // get Environment for syntax checking, number of cols is now part of env
+    void getEnv(int lineNumber, StackEnvironment &env) const; // get Environment for syntax checking, number of cols is now part of env
 	Q_INVOKABLE QString getLastEnvName(int lineNumber); // special function to use with javascript (insert "\item" from menu)
 
-	void enableSyntaxCheck(bool enable)
-	{
-		syntaxChecking = enable;
-        SynChecker.enableSyntaxCheck(enable);
-	}
+    void enableSyntaxCheck(bool enable);
+    Q_INVOKABLE bool isSubfileRoot();
+    bool saveCachingData(const QString &folder);
+    bool restoreCachedData(const QString &folder, const QString fileName);
+    bool isIncompleteInMemory();
+    void startSyntaxChecker();
+
+    struct HandledData {
+        QStringList removedUsepackages;
+        QStringList addedUsepackages;
+        QStringList handledUsepackages; // move packages from removed to handled if they were directly added in order to handle identical usepackage in one line better (#3556)
+        QStringList removedUserCommands;
+        QStringList addedUserCommands;
+        QStringList removedUserSnippets; // small snippets which automatically generated for completion only, e.g. x_y or \mathsf{as}
+        QStringList addedUserSnippets;
+        QStringList lstFilesToLoad;
+        QStringList removedIncludes;
+        QList<LatexDocument *> addedIncludes;
+        QStringList oldBibs;
+        bool completerNeedsUpdate = false;
+        bool bibItemsChanged = false;
+        bool bibTeXFilesNeedsUpdate = false;
+        bool updateSyntaxCheck = false;
+        int posLabel;
+        int posTodo;
+        int posBlock;
+        int posBibTeX;
+    };
+
+    int lexLines(int &lineNr,int &count,bool recheck=false);
+    void lexLinesSimple(const int lineNr,const int count);
+    void handleComments(QDocumentLineHandle *dlh, int &curLineNr, std::list<StructureEntry*>::iterator &docStructureIter);
+    void removeLineElements(QDocumentLineHandle *dlh, HandledData &changedCommands);
+    void handleRescanDocuments(HandledData changedCommands);
+    void interpretCommandArguments(QDocumentLineHandle *dlh, const int i, HandledData &data, bool recheckLabels, std::list<StructureEntry*>::iterator &docStructureIter);
+    void reinterpretCommandArguments(HandledData &changedCommands);
+    void replaceOrAdd(std::list<StructureEntry*>::iterator &docStructureIter, QDocumentLineHandle *dlh, StructureEntry *newElement);
+
+    void gatherCompletionFiles(QStringList &files, QStringList &loadedFiles, LatexPackage &pck, bool gatherForCompleter = false);
+
+    std::list<StructureEntry *> docStructure;
+
+    void setHideNonTextGrammarErrors(bool hide);
+    void setGrammarFormats(const QList<int> &formats);
 
 private:
 	QString fileName; //absolute
 	QString temporaryFileName; //absolute, temporary
 	QFileInfo fileInfo;
+    bool importedFile=false; /// mark if this file was loaded via import/subimport, i.e. inputs relative to this file instead of root !
 
 	LatexEditorView *edView;
 
 	LatexDocument *masterDocument;
 	QSet<LatexDocument *> childDocs;
 
-	StructureEntry *magicCommentList;
-	StructureEntry *labelList;
-	StructureEntry *todoList;
-	StructureEntry *bibTeXList;
-	StructureEntry *blockList;
-
 	QMultiHash<QDocumentLineHandle *, ReferencePair> mLabelItem;
 	QMultiHash<QDocumentLineHandle *, ReferencePair> mBibItem;
 	QMultiHash<QDocumentLineHandle *, ReferencePair> mRefItem;
@@ -233,6 +254,7 @@ private:
 	QMultiHash<QDocumentLineHandle *, UserCommandPair> mUserCommandList;
 	QMultiHash<QDocumentLineHandle *, QString> mUsepackageList;
 	QMultiHash<QDocumentLineHandle *, QString> mIncludedFilesList;
+    QMultiHash<QDocumentLineHandle *, QString> mImportedFilesList;
 
 	QList<QDocumentLineHandle *> mLineSnapshot;
 
@@ -246,27 +268,27 @@ private:
 	QDocumentLineHandle *mAppendixLine, *mBeyondEnd;
 
 	void updateContext(QDocumentLineHandle *oldLine, QDocumentLineHandle *newLine, StructureEntry::Context context);
-	void setContextForLines(StructureEntry *se, int startLine, int endLine, StructureEntry::Context context, bool state);
+    void setContextForLines(int startLine, int endLine, StructureEntry::Context context, bool state);
 
-	int findStructureParentPos(const QList<StructureEntry *> &children, QList<StructureEntry *> &removedElements, int linenr, int count);
+    void removeRangeFromStructure(int lineNr,int count);
 
-	bool IsInTree (StructureEntry *se);
-	void updateElementWithSignal(StructureEntry *se){ emit updateElement(se); }
-	void removeElementWithSignal(StructureEntry *se);
-	void addElementWithSignal(StructureEntry *parent, StructureEntry *se);
-	void insertElementWithSignal(StructureEntry *parent, int pos, StructureEntry *se);
-	void moveElementWithSignal(StructureEntry *se, StructureEntry *parent, int pos);
+    QStringList unrollStructure();
 
-	void addMagicComment(const QString &text, int lineNr, int posMagicComment);
+    void addMagicComment(const QString &text, int lineNr, std::list<StructureEntry*>::iterator &docStructureIter);
 	void parseMagicComment(const QString &name, const QString &val, StructureEntry *se);
 
-	void gatherCompletionFiles(QStringList &files, QStringList &loadedFiles, LatexPackage &pck, bool gatherForCompleter = false);
-
-	SyntaxCheck SynChecker;
+    SyntaxCheck synChecker;
 	Environment unclosedEnv;
 
 	bool syntaxChecking;
 
+    bool m_isSubfileRoot=false;
+
+    bool m_cachedDataOnly=false;
+
+    bool m_hideNonTextGrammarErrors=true;
+    QList<int> m_grammarFormats;
+
 #ifndef QT_NO_DEBUG
 public:
 	QSet<StructureEntry *> StructureContent;
@@ -275,29 +297,22 @@ public:
 
 public slots:
 	void updateStructure();
-	bool patchStructure(int linenr, int count, bool recheck = false);
-    void patchStructureRemoval(QDocumentLineHandle *dlh,int hint=-1);
+    void patchStructure(int linenr, int count, bool recheck = false);
+    void patchStructureRemoval(QDocumentLineHandle *dlh,int hint=-1,int count=1);
 	void initClearStructure();
-	void updateLtxCommands(bool updateAll = false);
-	void setLtxCommands(const LatexParser &cmds);
+    void updateLtxCommands(bool updateAll = false, bool updatePackages=true);
+    void addLtxCommands();
+    void setLtxCommands(QSharedPointer<LatexParser> cmds);
     void setSpeller(SpellerUtility *speller);
     void setReplacementList(QMap<QString,QString> replacementList);
 	void updateSettings();
     void checkNextLine(QDocumentLineHandle *dlh, bool clearOverlay, int ticket, int hint=-1);
 
 signals:
-	void hasBeenIncluded(const LatexDocument &newMasterDocument);
-    void structureUpdated(LatexDocument *document, StructureEntry *highlight = nullptr);
-    void setHighlightedEntry(StructureEntry *highlight);
-	void structureLost(LatexDocument *document);
-	void removeElement(StructureEntry *se, int row);
-	void removeElementFinished();
-	void addElement(StructureEntry *se, int row);
-	void addElementFinished();
-	void updateElement(StructureEntry *se);
+    void structureUpdated();
 	void updateCompleter();
+    void updateCompleterCommands();
 	void updateBibTeXFiles();
-	void toBeChanged();
 	void importPackage(QString name);
 	void spellingDictChanged(const QString &name);
 	void encodingChanged();
@@ -340,7 +355,7 @@ public:
     Q_PROPERTY(LatexDocument *masterDocument READ getMasterDocument)
     Q_PROPERTY(QList<LatexDocument *> documents READ getDocuments); //<- semicolon necessary due to qt bug 22992
 
-    Q_INVOKABLE LatexDocument *getRootDocumentForDoc(LatexDocument *doc = nullptr) const ; ///< no argument means current doc ...
+    Q_INVOKABLE LatexDocument *getRootDocumentForDoc(LatexDocument *doc = nullptr, bool breakAtSubfileRoot=false) const ; ///< no argument means current doc ...
 
 	Q_INVOKABLE QString getCurrentFileName() const; ///< returns the absolute file name of the current file or "" if none is opened
 	Q_INVOKABLE QString getCompileFileName() const; ///< returns the absolute file name of the file to be compiled (master or current)
@@ -355,6 +370,8 @@ public:
 	void reorder(const QList<LatexDocument *> &order);
 
 	void settingsRead();
+    void setCachingFolder(const QString &folder);
+    QString getCachingFolder() const;
 
 	Q_INVOKABLE bool singleMode() const;
 
@@ -377,18 +394,16 @@ public:
 
 
 	QHash<QString, LatexPackage> cachedPackages;
-	void addDocToLoad(QString filename);
+    std::pair<bool,bool> addDocsToLoad(QStringList filenames, LatexDocument *parentDocument, bool isHigherLevel=false);
 	void removeDocs(QStringList removeIncludes);
 	void hideDocInEditor(LatexEditorView *edView);
 	QString findPackageByCommand(const QString command);
-	void enablePatch(const bool enable);
-	bool patchEnabled();
 	void requestQNFAupdate();
 
 signals:
 	void masterDocumentChanged(LatexDocument *masterDocument);
 	void aboutToDeleteDocument(LatexDocument *document);
-	void docToLoad(QString filename);
+    void docsToLoad(QStringList filenames,QSharedPointer<LatexParser> lp);
 	void docToHide(LatexEditorView *edView);
 	void updateQNFA();
 
@@ -401,6 +416,7 @@ public slots:
 
 private:
 	bool m_patchEnabled;
+    QString m_cachingFolder;
 };
 
 #endif // LATEXDOCUMENT_H
