@@ -36,7 +36,7 @@ public:
 	bool allowDragAndDrop;
 	bool mouseWheelZoom, smoothScrolling, verticalOverScroll;
 
-	bool hackAutoChoose, hackDisableFixedPitch, hackDisableWidthCache, hackDisableLineCache, hackDisableAccentWorkaround, hackQImageCache;
+    bool hackAutoChoose, hackDisableFixedPitch, hackDisableWidthCache, hackDisableLineCache, hackDisableAccentWorkaround;
 	int hackRenderingMode; //0: normal, 1: qt (missing), 2: single letter
 	bool showPlaceholders;
 	int wordwrap; // 0 off, 1 soft wrap, 2 soft wrap fixed line width, 3 hard wrap fixed line width
