@@ -1318,10 +1318,14 @@ TokenStack getContext(QDocumentLineHandle *dlh, int pos)
 	TokenStack ts;
 	for (int i = 0; i < tl.length(); i++) {
 		Token tk = tl.at(i);
-        if (tk.start >= pos) {
-            // break if token is right of cursor, fix #3967
+        if (tk.start > pos) {
 			break;
 		}
+        if(tk.start == pos && tk.length>0){
+            // break if token is right of cursor, fix #3967
+            // also fix #4017
+            break;
+        }
         if (Token::tkClose().contains(tk.type) && !stack.isEmpty() ) {
             if (stack.top().type == Token::opposite(tk.type) && (tk.start<pos)) {
                 stack.pop();
