@@ -192,6 +192,7 @@ QSet<Token::TokenType> Token::tkOpen()
 	result.insert(openBracket);
 	result.insert(openSquare);
 	result.insert(less);
+    result.insert(openSquare);
 	return result;
 }
 
@@ -206,6 +207,7 @@ QSet<Token::TokenType> Token::tkClose()
 	result.insert(closeBracket);
 	result.insert(closeSquareBracket);
 	result.insert(greater);
+    result.insert(greater);
 	return result;
 }
 
@@ -242,6 +244,7 @@ QSet<Token::TokenType> Token::tkSingleArg()
 	result.insert(beamertheme);
 	result.insert(def);
 	result.insert(overlay);
+    result.insert(defSpecialArg);
 	return result;
 }
 
@@ -336,6 +339,7 @@ int Token::innerLength() const
  */
 QString Token::getText() const
 {
+    if(!dlh) return "";
 	dlh->lockForRead();
 	QString result = dlh->text().mid(start, length);
 	dlh->unlock();
