@@ -174,7 +174,6 @@ class QCE_EXPORT QDocument : public QObject
 			DisableLineCache            = 0x04,
 			ForceQTextLayout            = 0x08,
             ForceSingleCharacterDrawing = 0x10,
-            QImageCache = 0x20
 		};
 
 		Q_DECLARE_FLAGS(WorkAroundMode, WorkAroundFlag)
@@ -189,6 +188,17 @@ class QCE_EXPORT QDocument : public QObject
 
 		void load(const QString& file, QTextCodec* codec);
 
+        enum SaveErrorCode
+        {
+            success,
+            fileNotWritable,
+            noBackupFilenameAvailable,
+            backupFileNotRestored,
+            writingFailed,
+        };
+
+        SaveErrorCode save(const QString& filename);
+
 		QString getFileName() const;
 		QFileInfo getFileInfo() const;
 		QString getName() const;
