@@ -155,7 +155,7 @@ void ScriptEngineTest::scriptApp_data(){
 
     QTest::newRow("app.version")
         << "var a=app.getVersion();editor.setText(a, false)"
-        << QString::number(TXSVERSION_NUMERIC);
+        << QString::number(Version::parseVersionNumberToInt(TXSVERSION));
     QTest::newRow("app.currentFileName")
         << "var a=app.getCurrentFileName();editor.setText(a, false)"
         << "";
@@ -240,7 +240,7 @@ void ScriptEngineTest::getLineTokens(void)
 
 	if (!documentText.isEmpty()) {
 		edView->editor->setText(documentText, false);
-		edView->document->SynChecker.waitForQueueProcess(); // wait for syntax checker to finish (as it runs in a parallel thread)
+        edView->document->synChecker.waitForQueueProcess(); // wait for syntax checker to finish (as it runs in a parallel thread)
 	}
 	scriptengine eng(nullptr);
 	eng.setEditorView(edView);
