@@ -5,6 +5,7 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include "utilsVersion.h"
+#include <QLocale>
 
 class UpdateChecker : public QObject
 {
@@ -21,6 +22,7 @@ public:
 	void check(bool m_silent = true, int currentComboBoxUpdateLevel = -1);
 
 signals:
+	void dataParsed(QString versionNumber);
 	void checkCompleted();
 
 public slots:
